"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTextColors = exports.buttonHelper = exports.buttonColorHelper = void 0;
const colors_1 = require("../UikitUtils/colors");
const themeHelper_1 = require("../UikitUtils/themeHelper");
const Button_1 = require("./Button");
const buttonStyles_1 = require("./buttonStyles");
const buttonColorHelper = ({ styleArray, type, theme, }) => {
    if ((0, Button_1.isButtonTypeKey)(type)) {
        switch (type) {
            case 'primary':
                styleArray.push({ backgroundColor: (0, themeHelper_1.primaryButtonColor)(theme) });
                break;
            case 'secondary':
                let borderColor = (0, themeHelper_1.primaryButtonColor)(theme);
                styleArray.push(buttonStyles_1.styles.secondary, { borderColor });
                break;
            case 'success':
                styleArray.push({ backgroundColor: colors_1.SEMANTIC_SUCCESS_GREEN_PRIMARY });
                break;
            case 'tertiary':
                styleArray.push(buttonStyles_1.styles.tertiary);
                break;
            case 'link':
                styleArray.push(buttonStyles_1.styles.link);
                break;
            default:
                styleArray.push({ backgroundColor: (0, themeHelper_1.primaryColor)(theme) });
                break;
        }
    }
};
exports.buttonColorHelper = buttonColorHelper;
const buttonHelper = (styleArray, flex, curved, flat, disabled, theme, type, contain) => {
    if (flex) {
        styleArray.push({ flex });
    }
    if ((0, themeHelper_1.defaultButtonCurved)(theme) || curved) {
        styleArray.push(buttonStyles_1.styles.curved);
    }
    else if (flat) {
        styleArray.push(buttonStyles_1.styles.flat);
    }
    if (disabled && type === 'link') {
        styleArray.push(buttonStyles_1.styles.link);
    }
    else if (disabled && type === 'secondary') {
        styleArray.push(buttonStyles_1.styles.secondaryDisabled);
    }
    else if (disabled && type === 'tertiary') {
        styleArray.push(buttonStyles_1.styles.tertiaryDisabled);
    }
    else if (disabled) {
        styleArray.push(buttonStyles_1.styles.disabled);
    }
    if (contain) {
        // not working need to implement container like component
        styleArray.push(buttonStyles_1.styles.contain);
    }
};
exports.buttonHelper = buttonHelper;
const getTextColors = ({ type, theme, disabled }) => {
    let textColor = 'white';
    if (type !== 'link' && type === 'primary') {
        textColor = (0, themeHelper_1.primaryButtonTextColor)(theme);
    }
    if (type === 'secondary' && disabled) {
        textColor = 'gray';
    }
    else if (type === 'secondary') {
        textColor = 'theme';
    }
    if (type === 'link') {
        textColor = 'link';
    }
    if (type === 'tertiary' && disabled) {
        textColor = 'gray';
    }
    else if (type === 'tertiary') {
        textColor = 'black';
    }
    return textColor;
};
exports.getTextColors = getTextColors;
