"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint sonarjs/cognitive-complexity: ["error", 24] */
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const colors_1 = require("../UikitUtils/colors");
const styles = react_native_1.StyleSheet.create({
    normal: {
        backgroundColor: colors_1.WHITE,
    },
    noDrop: {
        shadowOffset: { width: 0, height: 0 },
        shadowRadius: 0,
        shadowOpacity: 0,
        elevation: 0,
    },
    gradientCard: {
        borderRadius: 10,
        elevation: 5,
        shadowColor: colors_1.BLACK,
        shadowOffset: { width: 0, height: 3 },
        shadowOpacity: 0.06,
        shadowRadius: 10,
    },
    alignNormal: {
        alignItems: 'flex-start',
        justifyContent: 'flex-start',
    },
    alignCenter: {
        alignItems: 'center',
        justifyContent: 'center',
    },
    alignStretch: {
        alignItems: 'stretch',
    },
    curved: {
        borderRadius: 28,
    },
    expanded: {
        flex: 1,
        flexDirection: 'row',
    },
    flat: {
        borderRadius: 0,
    },
    primary: {
        backgroundColor: colors_1.WHITE,
    },
    info: {
        backgroundColor: colors_1.SEMANTIC_INFO_BLUE_PRIMARY,
    },
    error: {
        backgroundColor: colors_1.SEMANTIC_RED_PRIMARY,
    },
    success: {
        backgroundColor: colors_1.SEMANTIC_SUCCESS_GREEN_PRIMARY,
    },
});
const defaultProps = {
    normal: true,
    align: 'center',
    type: 'primary',
};
const Card = ({ children, onClick, noDrop, align, curved, overrideStyle, flex, disabled, expanded, flat, 
// outline,
overrideContainerStyle, testID, type, }) => {
    // const {theme} = useContext(ThemeContext);
    const colorArray = [{}];
    const gradCardStyleArray = [styles.gradientCard];
    const containerStyle = [];
    if (flex) {
        gradCardStyleArray.push({ flex });
        containerStyle.push({ flex });
    }
    if (type === 'primary') {
        colorArray.push(styles.primary);
    }
    else if (type === 'info') {
        colorArray.push(styles.info);
    }
    else if (type === 'error') {
        colorArray.push(styles.error);
    }
    else if (type === 'success') {
        colorArray.push(styles.success);
    }
    else {
        colorArray.push({ backgroundColor: colors_1.WHITE });
    }
    if (align === 'normal') {
        gradCardStyleArray.push(styles.alignNormal);
        containerStyle.push(styles.alignNormal);
    }
    else if (align === 'stretch') {
        containerStyle.push(styles.alignStretch);
    }
    else {
        gradCardStyleArray.push(styles.alignCenter);
    }
    if (curved) {
        gradCardStyleArray.push(styles.curved);
    }
    if (flat) {
        gradCardStyleArray.push(styles.flat);
    }
    if (noDrop) {
        gradCardStyleArray.push(styles.noDrop);
    }
    if (expanded) {
        gradCardStyleArray.push(styles.expanded);
        containerStyle.push(styles.expanded);
    }
    if (overrideStyle) {
        gradCardStyleArray.push(overrideStyle);
    }
    if (overrideContainerStyle) {
        containerStyle.push(overrideContainerStyle);
    }
    return (react_1.default.createElement(react_native_1.View, { testID: "cardComponent", style: [colorArray, gradCardStyleArray] },
        react_1.default.createElement(react_native_1.TouchableOpacity, { testID: testID, onPress: onClick, disabled: disabled, style: [containerStyle] }, children)));
};
Card.defaultProps = defaultProps;
exports.default = Card;
