"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_image_crop_picker_1 = __importDefault(require("react-native-image-crop-picker"));
const Button_1 = __importDefault(require("../Button/Button"));
const Card_1 = __importDefault(require("../Card/Card"));
const Flex_1 = __importDefault(require("../Flex/Flex"));
const Modal_1 = __importDefault(require("../Modal/Modal"));
const Text_1 = __importDefault(require("../Text/Text"));
const styles = react_native_1.StyleSheet.create({
    overAll: {
        paddingHorizontal: 24,
        paddingVertical: 30,
    },
    chooseBtn: {
        marginVertical: 20,
    },
    takeBtn: {
        marginTop: 30,
    },
    marginTop: {
        marginTop: 20,
    },
});
const DocumentPicker = ({ open, close, onChange, includeBase64 }) => {
    const handleTakePhoto = () => {
        react_native_image_crop_picker_1.default.openCamera({
            width: 1200,
            height: 1200,
            cropping: true,
            includeBase64,
        })
            .then(image => {
            onChange(image);
            close();
        })
            .catch(() => {
            if (react_native_1.Platform.OS === 'ios') {
                react_native_1.Alert.alert('Permission', 'Device camera permission blocked. Enable the camera permission manually', [
                    {
                        text: 'Cancel',
                        onPress: () => { },
                    },
                    {
                        text: 'Enable',
                        onPress: () => {
                            react_native_1.Linking.openSettings();
                        },
                    },
                ]);
            }
        });
    };
    const handleChooseGallery = () => {
        react_native_image_crop_picker_1.default.openPicker({
            width: 1200,
            height: 1200,
            cropping: true,
            mediaType: 'photo',
            includeBase64,
        })
            .then(image => {
            onChange(image);
            close();
        })
            .catch(() => {
            if (react_native_1.Platform.OS === 'ios') {
                react_native_1.Alert.alert('Permission', 'Device photos permission blocked. Enable the photos permission manually', [
                    {
                        text: 'Cancel',
                        onPress: () => { },
                    },
                    {
                        text: 'Enable',
                        onPress: () => {
                            react_native_1.Linking.openSettings();
                        },
                    },
                ]);
            }
        });
    };
    return (react_1.default.createElement(Modal_1.default, { open: open, animationType: 'fade' },
        react_1.default.createElement(Card_1.default, { align: "stretch", overrideStyle: styles.overAll },
            react_1.default.createElement(Flex_1.default, null,
                react_1.default.createElement(Text_1.default, { align: "center", size: 18, bold: true }, "Upload Photo"),
                react_1.default.createElement(Text_1.default, { align: "center", color: "gray", overrideStyle: styles.marginTop }, "Choose Your Profile Picture"),
                react_1.default.createElement(Button_1.default, { overrideStyle: styles.takeBtn, onClick: handleTakePhoto }, "Take Photo"),
                react_1.default.createElement(Button_1.default, { overrideStyle: styles.chooseBtn, onClick: handleChooseGallery }, "Choose From Gallery"),
                react_1.default.createElement(Button_1.default, { onClick: close, type: "secondary" }, "Cancel")))));
};
exports.default = DocumentPicker;
