"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.onSuccessLoad = void 0;
const react_1 = __importStar(require("react"));
const react_native_1 = require("react-native");
const validators_1 = require("../UikitUtils/validators");
const colors_1 = require("../UikitUtils/colors");
const Modal_1 = __importDefault(require("../Modal/Modal"));
const Flex_1 = __importDefault(require("../Flex/Flex"));
const Button_1 = __importDefault(require("../Button/Button"));
const SvgClose_1 = __importDefault(require("../icons/SvgClose"));
const { width: windowWidth } = react_native_1.Dimensions.get('window');
const styles = react_native_1.StyleSheet.create({
    overAll: {
        backgroundColor: colors_1.WHITE,
        borderRadius: 10,
        position: 'relative',
    },
    svgClose: {
        position: 'absolute',
        zIndex: 11,
        top: 16,
        right: 16,
    },
    imagePreviewSize: {
        height: '80%',
        width: '80%',
    },
});
const defaultProps = {
    size: 250,
    overrideStyle: {},
    previewMode: false,
};
const onSuccessLoad = (imageWidth, imageHeight, props, setWidth, setHeight, setSizeMode) => {
    const { responsive, size } = props;
    if (!responsive) {
        return;
    }
    if (imageWidth < size) {
        setWidth(imageWidth);
    }
    else if (imageWidth < windowWidth) {
        setWidth(imageWidth * 0.4);
        setSizeMode('contain');
    }
    else {
        setWidth(windowWidth * 0.8);
        setSizeMode('contain');
    }
    if (imageHeight < size) {
        setHeight(imageHeight);
    }
    else {
        setHeight(imageHeight * 0.4);
        setSizeMode('contain');
    }
};
exports.onSuccessLoad = onSuccessLoad;
const Image = ({ src, overrideStyle, resizeMode, responsive, size, alt, height, width, testID, previewMode, headers, }) => {
    const [isOpenPreview, setOpenPreview] = (0, react_1.useState)(false);
    const imgHeight = responsive ? size : height;
    const imgWidth = responsive ? size : width;
    const [currentHeight, setHeight] = (0, react_1.useState)(imgHeight);
    const [currentWidth, setWidth] = (0, react_1.useState)(imgWidth);
    const [showImagePlaceholder, setShowImagePlaceholder] = (0, react_1.useState)(false);
    const [imageContainerStyle, setImageContainerStyle] = (0, react_1.useState)([]);
    let requiredResizeMode;
    if (!(0, validators_1.isEmpty)(resizeMode)) {
        requiredResizeMode = resizeMode;
    }
    if (responsive) {
        requiredResizeMode = 'cover';
    }
    const [sizeMode, setSizeMode] = (0, react_1.useState)(requiredResizeMode);
    (0, react_1.useEffect)(() => {
        setImageContainerStyle([
            { height: currentHeight, width: currentWidth },
            overrideStyle,
        ]);
    }, [currentHeight, currentWidth]);
    const accessibilityLabel = alt || src;
    const failure = () => {
        setShowImagePlaceholder(true);
    };
    if (src && typeof react_native_1.Image.getSize === 'function') {
        react_native_1.Image.getSize(src, (imageWidth, imageHeight) => (0, exports.onSuccessLoad)(imageWidth, imageHeight, { responsive, size }, setWidth, setHeight, setSizeMode), failure);
    }
    const handlePreview = (value) => {
        if (value) {
            setOpenPreview(true);
        }
        else {
            setOpenPreview(false);
        }
    };
    if (showImagePlaceholder) {
        return (react_1.default.createElement(react_native_1.View, { style: [imageContainerStyle, { backgroundColor: colors_1.GRAY_90 }], testID: "image-placeholder" }));
    }
    if (isOpenPreview) {
        return (react_1.default.createElement(Modal_1.default, { animationType: 'slide', open: isOpenPreview },
            react_1.default.createElement(Flex_1.default, { center: true, middle: true, overrideStyle: styles.overAll },
                react_1.default.createElement(Button_1.default, { onClick: () => handlePreview(false), type: "link", overrideStyle: styles.svgClose },
                    react_1.default.createElement(SvgClose_1.default, { fill: colors_1.GRAY_70 })),
                react_1.default.createElement(react_native_1.Image, { style: styles.imagePreviewSize, source: { uri: (0, validators_1.secureImage)(src) }, resizeMode: sizeMode, accessibilityLabel: accessibilityLabel, accessible: true }))));
    }
    return (react_1.default.createElement(react_native_1.TouchableOpacity, { disabled: !previewMode, onPress: () => handlePreview(true) },
        react_1.default.createElement(react_native_1.Image, { accessible: true, source: { uri: (0, validators_1.secureImage)(src), headers }, style: imageContainerStyle, resizeMode: sizeMode, accessibilityLabel: accessibilityLabel, testID: testID })));
};
Image.defaultProps = defaultProps;
exports.default = (0, react_1.memo)(Image, (prevProps, nextProps) => prevProps.src === nextProps.src);
